est_delta: This function select the optimal thresholding level delta

View source: R/select_threshold.R

est_deltaR Documentation

This function select the optimal thresholding level delta

Description

This function select the optimal thresholding level delta

Usage

est_delta(
  data,
  method = c("cv", "qiu"),
  operator = c("hard", "soft", "scad", "al")
)

Arguments

data

The data matrix.

method

The choice of method to select the optimal threshold level.

operator

The choice of thresholding operator.

Value

The optimal threshold level.

Examples

## generate data from a block diagonal covariance matrix structure
n <- 50
p <- 30
data.true.cov <- block.true.cov(p)
data <- sampleMVN(n, data.true.cov, sparse=TRUE)
## select the optimal thresholding level delta
delta <- est_delta(data, method='cv', operator='scad')

sparseCov documentation built on May 29, 2024, 1:38 a.m.