View source: R/select_threshold.R
| est_delta | R Documentation |
This function select the optimal thresholding level delta
est_delta(
data,
method = c("cv", "qiu"),
operator = c("hard", "soft", "scad", "al")
)
data |
The data matrix. |
method |
The choice of method to select the optimal threshold level. |
operator |
The choice of thresholding operator. |
The optimal threshold level.
## generate data from a block diagonal covariance matrix structure
n <- 50
p <- 30
data.true.cov <- block.true.cov(p)
data <- sampleMVN(n, data.true.cov, sparse=TRUE)
## select the optimal thresholding level delta
delta <- est_delta(data, method='cv', operator='scad')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.